gedidb.L4ABeam
==============

.. currentmodule:: gedidb

.. autoclass:: L4ABeam

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~L4ABeam.__init__
      ~L4ABeam.apply_filter
      ~L4ABeam.build_virtual_dataset
      ~L4ABeam.clear
      ~L4ABeam.copy
      ~L4ABeam.create_dataset
      ~L4ABeam.create_dataset_like
      ~L4ABeam.create_group
      ~L4ABeam.create_virtual_dataset
      ~L4ABeam.get
      ~L4ABeam.items
      ~L4ABeam.keys
      ~L4ABeam.move
      ~L4ABeam.pop
      ~L4ABeam.popitem
      ~L4ABeam.require_dataset
      ~L4ABeam.require_group
      ~L4ABeam.setdefault
      ~L4ABeam.update
      ~L4ABeam.values
      ~L4ABeam.visit
      ~L4ABeam.visit_links
      ~L4ABeam.visititems
      ~L4ABeam.visititems_links
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~L4ABeam.attrs
      ~L4ABeam.beam_type
      ~L4ABeam.field_mapper
      ~L4ABeam.file
      ~L4ABeam.id
      ~L4ABeam.main_data
      ~L4ABeam.n_shots
      ~L4ABeam.name
      ~L4ABeam.parent
      ~L4ABeam.ref
      ~L4ABeam.regionref
   
   